@@ -1,5 +1,5 @@
 #
-# $Id: Status.pm,v 1.18 1996/07/17 11:39:25 aas Exp $
+# $Id: Status.pm,v 1.21 1997/12/10 13:12:17 aas Exp $
 
 package HTTP::Status;
 
@@ -23,57 +23,58 @@ HTTP::Status - HTTP Status code processing
 
 =head1 DESCRIPTION
 
-HTTP::Status is a library of routines for defining and classification
-of HTTP status codes for libwww-perl.  Status codes are used to encode
-the overall outcome of a HTTP response message.  Codes correspond to
-those defined in E<lt>draft-ietf-http-v11-spec-06>.
+I<HTTP::Status> is a library of routines for defining and
+classification of HTTP status codes for libwww-perl.  Status codes are
+used to encode the overall outcome of a HTTP response message.  Codes
+correspond to those defined in RFC 2068.
 
-The following functions can be used as mnemonic status code names:
+=head1 CONSTANTS
 
-   RC_CONTINUE
-   RC_SWITCHING_PROTOCOLS
-   RC_OK
-   RC_CREATED
-   RC_ACCEPTED
-   RC_NON_AUTHORITATIVE_INFORMATION
-   RC_NO_CONTENT
-   RC_RESET_CONTENT
-   RC_PARTIAL_CONTENT
-   RC_MULTIPLE_CHOICES
-   RC_MOVED_PERMANENTLY
-   RC_MOVED_TEMPORARILY
-   RC_SEE_OTHER
-   RC_NOT_MODIFIED
-   RC_USE_PROXY
-   RC_BAD_REQUEST
-   RC_UNAUTHORIZED
-   RC_PAYMENT_REQUIRED
-   RC_FORBIDDEN
-   RC_NOT_FOUND
-   RC_METHOD_NOT_ALLOWED
-   RC_NOT_ACCEPTABLE
-   RC_PROXY_AUTHENTICATION_REQUIRED
-   RC_REQUEST_TIMEOUT
-   RC_CONFLICT
-   RC_GONE
-   RC_LENGTH_REQUIRED
-   RC_PRECONDITION_FAILED
-   RC_REQUEST_ENTITY_TOO_LARGE
-   RC_REQUEST_URI_TOO_LARGE
-   RC_UNSUPPORTED_MEDIA_TYPE
-   RC_INTERNAL_SERVER_ERROR
-   RC_NOT_IMPLEMENTED
-   RC_BAD_GATEWAY
-   RC_SERVICE_UNAVAILABLE
-   RC_GATEWAY_TIMEOUT
-   RC_HTTP_VERSION_NOT_SUPPORTED
+The following constant functions can be used as mnemonic status code
+names:
 
-The status_message() function will translate status codes to human
-readable strings.
+   RC_CONTINUE				(100)
+   RC_SWITCHING_PROTOCOLS		(101)
 
-The is_info(), is_success(), is_error(), and is_redirect() functions
-will return a TRUE value if the passed status code indicates success,
-and error, or a redirect respectively.
+   RC_OK				(200)
+   RC_CREATED				(201)
+   RC_ACCEPTED				(202)
+   RC_NON_AUTHORITATIVE_INFORMATION	(203)
+   RC_NO_CONTENT			(204)
+   RC_RESET_CONTENT			(205)
+   RC_PARTIAL_CONTENT			(206)
+
+   RC_MULTIPLE_CHOICES			(300)
+   RC_MOVED_PERMANENTLY			(301)
+   RC_MOVED_TEMPORARILY			(302)
+   RC_SEE_OTHER				(303)
+   RC_NOT_MODIFIED			(304)
+   RC_USE_PROXY				(305)
+
+   RC_BAD_REQUEST			(400)
+   RC_UNAUTHORIZED			(401)
+   RC_PAYMENT_REQUIRED			(402)
+   RC_FORBIDDEN				(403)
+   RC_NOT_FOUND				(404)
+   RC_METHOD_NOT_ALLOWED		(405)
+   RC_NOT_ACCEPTABLE			(406)
+   RC_PROXY_AUTHENTICATION_REQUIRED	(407)
+   RC_REQUEST_TIMEOUT			(408)
+   RC_CONFLICT				(409)
+   RC_GONE				(410)
+   RC_LENGTH_REQUIRED			(411)
+   RC_PRECONDITION_FAILED		(412)
+   RC_REQUEST_ENTITY_TOO_LARGE		(413)
+   RC_REQUEST_URI_TOO_LARGE		(414)
+   RC_UNSUPPORTED_MEDIA_TYPE		(415)
+   RC_REQUEST_RANGE_NOT_SATISFIABLE     (416)
+
+   RC_INTERNAL_SERVER_ERROR		(500)
+   RC_NOT_IMPLEMENTED			(501)
+   RC_BAD_GATEWAY			(502)
+   RC_SERVICE_UNAVAILABLE		(503)
+   RC_GATEWAY_TIMEOUT			(504)
+   RC_HTTP_VERSION_NOT_SUPPORTED	(505)
 
 =cut
 
@@ -83,6 +84,7 @@ and error, or a redirect respectively.
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw(is_info is_success is_redirect is_error status_message);
+@EXPORT_OK = qw(is_client_error is_server_error);
 
 # Note also addition of mnemonics to @EXPORT below
 
@@ -118,6 +120,7 @@ my %StatusCode = (
     413 => 'Request Entity Too Large',
     414 => 'Request-URI Too Large',
     415 => 'Unsupported Media Type',
+    416 => 'Request Range Not Satisfiable',
     500 => 'Internal Server Error',
     501 => 'Not Implemented',
     502 => 'Bad Gateway',
@@ -139,10 +142,18 @@ while (($code, $message) = each %StatusCode) {
 eval $mnemonicCode; # only one eval for speed
 die if $@;
 
+=head1 FUNCTIONS
 
-=head2 status_message($code)
+The following additional functions are provided.  Most of them are
+exported by default.
 
-Return user friendly error message for status code C<$code>
+=over 4
+
+=item status_message($code)
+
+The status_message() function will translate status codes to human
+readable strings. The string is the same as found in the constant
+names above.
 
 =cut
 
@@ -152,21 +163,34 @@ sub status_message ($)
     $StatusCode{$_[0]};
 }
 
-=head2 is_info($code)
+=item is_info($code)
 
-Return TRUE if C<$code> is an Informational status code
+Return TRUE if C<$code> is an I<Informational> status code.
 
-=head2 is_success($code)
+=item is_success($code)
 
-Return TRUE if C<$code> is a Successful status code
+Return TRUE if C<$code> is a I<Successful> status code.
 
-=head2 is_redirect($code)
+=item is_redirect($code)
 
-Return TRUE if C<$code> is a Redirection status code
+Return TRUE if C<$code> is a I<Redirection> status code.
 
-=head2 is_error($code)
+=item is_error($code)
 
-Return TRUE if C<$code> is an Error status code
+Return TRUE if C<$code> is an I<Error> status code.  The function
+return TRUE for both client error or a server error status codes.
+
+=item is_client_error($code)
+
+Return TRUE if C<$code> is an I<Client Error> status code.  This
+function is B<not> exported by default.
+
+=item is_server_error($code)
+
+Return TRUE if C<$code> is an I<Server Error> status code.   This
+function is B<not> exported by default.
+
+=back
 
 =cut
 
