@@ -1,5 +1,5 @@
 #
-# $Id: http.pm,v 1.31 1997/05/30 09:27:11 aas Exp $
+# $Id: http.pm,v 1.33 1997/12/12 10:09:53 aas Exp $
 
 package LWP::Protocol::http;
 
@@ -21,6 +21,11 @@ my $endl         = "\015\012";     # how lines should be terminated;
 				   # "\r\n" is not correct on all systems, for
 				   # instance MacPerl defines it to "\012\015"
 
+sub _new_socket
+{
+    LWP::Socket->new;
+}
+
 sub request
 {
     my($self, $request, $proxy, $arg, $size, $timeout) = @_;
@@ -55,7 +60,7 @@ sub request
     alarm($timeout) if $self->use_alarm and $timeout;
 
     # connect to remote site
-    my $socket = new LWP::Socket;
+    my $socket = $self->_new_socket();
     $socket->connect($host, $port);
 
     my $request_line = "$method $fullpath $httpversion$endl";
@@ -83,7 +88,16 @@ sub request
 
     # HTTP/1.1 will require us to send the 'Host' header, so we might
     # as well start now.
-    $request->header('Host', $url->netloc);
+    {
+	my $host = $url->netloc;
+	$host =~ s/^([^\@]*)\@//;  # get rid of potential "user:pass@"
+	$request->header('Host' => $host);
+
+	# add authorization header if we need them
+	if (defined($1) && not $request->header('Authorization')) {
+	    $request->authorization_basic($url->user, $url->password);
+	}
+    }
 
     $socket->write($request_line . $request->headers_as_string($endl) . $endl);
     if (defined $content) {
